@@ -1,9 +1,11 @@
+# frozen_string_literal: true
+
 require 'ruby2_keywords'
 require 'mocha/expectation'
 require 'mocha/expectation_list'
 require 'mocha/invocation'
-require 'mocha/names'
-require 'mocha/receivers'
+require 'mocha/default_name'
+require 'mocha/default_receiver'
 require 'mocha/method_matcher'
 require 'mocha/parameters_matcher'
 require 'mocha/argument_iterator'
@@ -35,6 +37,9 @@ module Mocha
   # while an +expects(:foo).at_least_once+ expectation will always be matched
   # against invocations.
   #
+  # However, note that if the expectation that matches the invocation has a
+  # cardinality of "never", then an unexpected invocation error is reported.
+  #
   # This scheme allows you to:
   #
   # - Set up default stubs in your the +setup+ method of your test class and
@@ -111,8 +116,7 @@ module Mocha
     def expects(method_name_or_hash, backtrace = nil)
       expectation = nil
       iterator = ArgumentIterator.new(method_name_or_hash)
-      iterator.each do |*args|
-        method_name = args.shift
+      iterator.each do |method_name, *args|
         ensure_method_not_already_defined(method_name)
         expectation = Expectation.new(self, method_name, backtrace)
         expectation.in_sequence(@mockery.sequences.last) if @mockery.sequences.any?
@@ -150,8 +154,7 @@ module Mocha
     def stubs(method_name_or_hash, backtrace = nil)
       expectation = nil
       iterator = ArgumentIterator.new(method_name_or_hash)
-      iterator.each do |*args|
-        method_name = args.shift
+      iterator.each do |method_name, *args|
         ensure_method_not_already_defined(method_name)
         expectation = Expectation.new(self, method_name, backtrace)
         expectation.at_least(0)
@@ -273,8 +276,9 @@ module Mocha
     end
 
     # @private
-    def initialize(mockery, name = nil, receiver = nil)
+    def initialize(mockery, assertion_counter, name = nil, receiver = nil)
       @mockery = mockery
+      @assertion_counter = assertion_counter
       @name = name || DefaultName.new(self)
       @receiver = receiver || DefaultReceiver.new(self)
       @expectations = ExpectationList.new
@@ -312,13 +316,13 @@ module Mocha
     end
 
     # @private
-    def method_missing(symbol, *arguments, &block) # rubocop:disable Style/MethodMissingSuper
+    def method_missing(symbol, *arguments, &block)
       handle_method_call(symbol, arguments, block)
     end
     ruby2_keywords(:method_missing)
 
     # @private
-    def handle_method_call(symbol, arguments, block) # rubocop:disable Metrics/CyclomaticComplexity, Metrics/PerceivedComplexity
+    def handle_method_call(symbol, arguments, block)
       check_expiry
       check_responder_responds_to(symbol)
       invocation = Invocation.new(self, symbol, arguments, block)
@@ -326,15 +330,11 @@ module Mocha
       matching_expectations = all_expectations.matching_expectations(invocation)
 
       index = 0
-      never_allowed_expectation = nil
       while index < matching_expectations.length
         matching_expectation = matching_expectations[index]
         if matching_expectation.invocations_never_allowed?
-          never_allowed_expectation = matching_expectation
+          raise_unexpected_invocation_error(invocation, matching_expectation)
         elsif matching_expectation.invocations_allowed?
-          if never_allowed_expectation
-            invocation_not_allowed_warning(invocation, never_allowed_expectation)
-          end
           return matching_expectation.invoke(invocation)
         end
         index += 1
@@ -356,8 +356,8 @@ module Mocha
     end
 
     # @private
-    def __verified__?(assertion_counter = nil)
-      @expectations.verified?(assertion_counter)
+    def __verified__?
+      @expectations.verified?(@assertion_counter)
     end
 
     # @private
@@ -387,18 +387,13 @@ module Mocha
 
     private
 
-    def invocation_not_allowed_warning(invocation, expectation)
-      messages = [
-        "The expectation defined at #{expectation.definition_location} does not allow invocations, but #{invocation.call_description} was invoked.",
-        'This invocation will cause the test to fail fast in a future version of Mocha.'
-      ]
-      Deprecation.warning(messages.join(' '))
-    end
-
     def raise_unexpected_invocation_error(invocation, matching_expectation)
       if @unexpected_invocation.nil?
         @unexpected_invocation = invocation
-        matching_expectation.invoke(invocation) if matching_expectation
+        if matching_expectation
+          matching_expectation.invoke(invocation)
+          @assertion_counter.increment
+        end
         call_description = @unexpected_invocation.call_description
         if matching_expectation && !matching_expectation.in_correct_order?
           call_description += ' invoked out of order'
