@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Mocha
   # Matcher classes used as parameters for {Expectation#with} to restrict the parameter values which will match the expectation. Can be nested. Build matcher instances in tests using methods in {Methods}, e.g. {Methods#includes}.
   module ParameterMatchers
@@ -6,7 +8,6 @@ module Mocha
   end
 end
 
-require 'mocha/parameter_matchers/deprecations'
 require 'mocha/parameter_matchers/instance_methods'
 
 require 'mocha/parameter_matchers/all_of'
