@@ -1,5 +1,6 @@
-require 'mocha/parameter_matchers/base'
-require 'mocha/parameter_matchers/deprecations'
+# frozen_string_literal: true
+
+require 'mocha/parameter_matchers/base_methods'
 
 module Mocha
   module ParameterMatchers
@@ -27,8 +28,6 @@ module Mocha
       end
     end
 
-    define_deprecated_matcher_method(:all_of)
-
     # Parameter matcher which combines a number of other matchers using a logical AND.
     class AllOf
       include BaseMethods
@@ -49,7 +48,5 @@ module Mocha
         "all_of(#{@matchers.map(&:mocha_inspect).join(', ')})"
       end
     end
-
-    provide_deprecated_access_to(:AllOf)
   end
 end
