@@ -1,5 +1,6 @@
-require 'mocha/parameter_matchers/base'
-require 'mocha/parameter_matchers/deprecations'
+# frozen_string_literal: true
+
+require 'mocha/parameter_matchers/base_methods'
 
 module Mocha
   module ParameterMatchers
@@ -25,8 +26,6 @@ module Mocha
       end
     end
 
-    define_deprecated_matcher_method(:any_parameters)
-
     # Parameter matcher which always matches whatever the parameters.
     class AnyParameters
       include BaseMethods
@@ -44,7 +43,5 @@ module Mocha
         'any_parameters'
       end
     end
-
-    provide_deprecated_access_to(:AnyParameters)
   end
 end
