@@ -1,8 +1,9 @@
+# frozen_string_literal: true
+
 require File.expand_path('../../../test_helper', __FILE__)
 
 require 'mocha/parameter_matchers/is_a'
 require 'mocha/inspect'
-require 'parameter_matchers_test_helper'
 
 class IsATest < Mocha::TestCase
   include Mocha::ParameterMatchers::Methods
@@ -21,7 +22,4 @@ class IsATest < Mocha::TestCase
     matcher = is_a(Integer)
     assert_equal 'is_a(Integer)', matcher.mocha_inspect
   end
-
-  include ParameterMatchersTestHelper.deprecation_tests_for_matcher_method(:is_a, Integer)
-  include ParameterMatchersTestHelper.deprecation_tests_for_matcher_class(:IsA)
 end
